@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Command;
-$Footprintless::Command::VERSION = '1.15';
+$Footprintless::Command::VERSION = '1.16';
 # ABSTRACT: A factory for building common commands
 # PODNAME: Footprintless::Command
 
@@ -110,7 +110,10 @@ sub cp_command {
                         'pv -f -s `',
                         _sudo_command(
                             $source_command_options
-                                && $source_command_options->get_sudo_username(),
+                            ? ( $source_command_options->get_sudo_command(),
+                                $source_command_options->get_sudo_username()
+                                )
+                            : ( undef, undef ),
                             pipe_command( "du -sb $source_path", 'cut -f1' )
                         ),
                         '`'
@@ -125,7 +128,10 @@ sub cp_command {
                 @destination_parts,
                 _sudo_command(
                     $destination_command_options
-                        && $destination_command_options->get_sudo_username(),
+                    ? ( $destination_command_options->get_sudo_command(),
+                        $destination_command_options->get_sudo_username()
+                        )
+                    : ( undef, undef ),
                     "tar --no-overwrite-dir -x -C $destination_path"
                 )
             );
@@ -251,9 +257,12 @@ sub sed_command {
 }
 
 sub _sudo_command {
-    my ( $sudo_username, $command ) = @_;
+    my ( $sudo_command, $sudo_username, $command ) = @_;
     if ( defined($sudo_username) ) {
-        $command = "sudo " . ( $sudo_username ? "-u $sudo_username " : '' ) . $command;
+        $command =
+              ( $sudo_command  ? "$sudo_command "     : 'sudo ' )
+            . ( $sudo_username ? "-u $sudo_username " : '' )
+            . $command;
     }
     return $command;
 }
@@ -313,13 +322,14 @@ sub wrap {
     my $wrap_options = shift;
     my $builder      = pop;
     my @args         = @_;
-    my ( $ssh, $username, $hostname, $sudo_username, $pretty );
+    my ( $ssh, $username, $hostname, $sudo_command, $sudo_username, $pretty );
 
     if ( ref( $args[$#args] ) eq 'Footprintless::Command::CommandOptions' ) {
         my $options = pop(@args);
         $ssh           = $options->get_ssh() || 'ssh';
         $username      = $options->get_username();
         $hostname      = $options->get_hostname();
+        $sudo_command  = $options->get_sudo_command();
         $sudo_username = $options->get_sudo_username();
         $pretty        = $options->get_pretty();
     }
@@ -338,7 +348,7 @@ sub wrap {
 
             $command =~ s/^(.*?[^\\]);$/$1/;    # from find -exec
 
-            $command = _sudo_command( $sudo_username, $command );
+            $command = _sudo_command( $sudo_command, $sudo_username, $command );
 
             $destination_command .= $command;
         }
@@ -364,7 +374,7 @@ sub wrap {
 }
 
 package Footprintless::Command::CommandOptions;
-$Footprintless::Command::CommandOptions::VERSION = '1.15';
+$Footprintless::Command::CommandOptions::VERSION = '1.16';
 sub new {
     return bless( {}, shift )->_init(@_);
 }
@@ -381,6 +391,9 @@ sub clone {
     if ( exists( $instance->{username} ) && !exists( $options{username} ) ) {
         $options{username} = $instance->{username};
     }
+    if ( exists( $instance->{sudo_command} ) && !exists( $options{sudo_command} ) ) {
+        $options{sudo_command} = $instance->{sudo_command};
+    }
     if ( exists( $instance->{sudo_username} ) && !exists( $options{sudo_username} ) ) {
         $options{sudo_username} = $instance->{sudo_username};
     }
@@ -403,6 +416,10 @@ sub get_ssh {
     return $_[0]->{ssh};
 }
 
+sub get_sudo_command {
+    return $_[0]->{sudo_command};
+}
+
 sub get_sudo_username {
     return $_[0]->{sudo_username};
 }
@@ -417,6 +434,7 @@ sub _init {
     $self->{hostname}      = $options{hostname}      if ( defined( $options{hostname} ) );
     $self->{ssh}           = $options{ssh}           if ( defined( $options{ssh} ) );
     $self->{username}      = $options{username}      if ( defined( $options{username} ) );
+    $self->{sudo_command}  = $options{sudo_command}  if ( defined( $options{sudo_command} ) );
     $self->{sudo_username} = $options{sudo_username} if ( defined( $options{sudo_username} ) );
     $self->{pretty}        = $options{pretty}        if ( defined( $options{pretty} ) );
 
@@ -433,7 +451,7 @@ Footprintless::Command - A factory for building common commands
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 SYNOPSIS
 
@@ -534,6 +552,13 @@ The ssh command to use, defaults to C<ssh>.  You can use this to specify other
 commands like C<plink> for windows or an implementation of C<ssh> that is not
 in your path.
 
+=item sudo_command
+
+The actual C<sudo> command.  Most likely you will want to leave this undefined
+and let C<sudo> be found in your C<$PATH>.  However, if for some reason you 
+need to use a different version (ex: C</usr/depot/bin/sudo>, then this provides 
+that option.
+
 =item sudo_username
 
 Prefixes your command thusly: C<sudo -u $sudo_username $command>.  If combined
