@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::CommandOptionsFactory;
-$Footprintless::CommandOptionsFactory::VERSION = '1.15';
+$Footprintless::CommandOptionsFactory::VERSION = '1.16';
 # ABSTRACT: A factory for creating command options
 # PODNAME: Footprintless::CommandOptionsFactory
 
@@ -19,6 +19,7 @@ sub command_options {
 
     $options{ssh} = $self->{default_ssh} unless ( $options{ssh} );
     delete( $options{sudo_username} ) unless ( $options{sudo_username} );
+    delete( $options{sudo_command} )  unless ( $options{sudo_command} );
     delete( $options{username} )      unless ( $options{username} );
     if (   $self->{localhost}
         && $options{hostname}
@@ -52,7 +53,7 @@ Footprintless::CommandOptionsFactory - A factory for creating command options
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 DESCRIPTION
 
@@ -70,6 +71,7 @@ scalar values.  Their defaults are:
 
     hostname => undef,
     ssh => 'ssh -q',
+    sudo_command => undef,
     sudo_username => undef,
     username => undef
 
